package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysTreeDict;
import com.ruoyi.system.service.ISysTreeDictService;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 树形字典Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/system/treeDict")
public class SysTreeDictController extends BaseController
{
    @Autowired
    private ISysTreeDictService sysTreeDictService;

    /**
     * 查询树形字典列表
     */
    @PreAuthorize("@ss.hasPermi('system:treeDict:list')")
    @GetMapping("/list")
    public AjaxResult list(SysTreeDict sysTreeDict)
    {
        List<SysTreeDict> list = sysTreeDictService.selectSysTreeDictList(sysTreeDict);
        return success(list);
    }

    /**
     * 导出树形字典列表
     */
    @PreAuthorize("@ss.hasPermi('system:treeDict:export')")
    @Log(title = "树形字典", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysTreeDict sysTreeDict)
    {
        List<SysTreeDict> list = sysTreeDictService.selectSysTreeDictList(sysTreeDict);
        ExcelUtil<SysTreeDict> util = new ExcelUtil<SysTreeDict>(SysTreeDict.class);
        util.exportExcel(response, list, "树形字典数据");
    }

    /**
     * 获取树形字典详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:treeDict:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysTreeDictService.selectSysTreeDictById(id));
    }

    /**
     * 新增树形字典
     */
    @PreAuthorize("@ss.hasPermi('system:treeDict:add')")
    @Log(title = "树形字典", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysTreeDict sysTreeDict)
    {
        return toAjax(sysTreeDictService.insertSysTreeDict(sysTreeDict));
    }

    /**
     * 修改树形字典
     */
    @PreAuthorize("@ss.hasPermi('system:treeDict:edit')")
    @Log(title = "树形字典", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysTreeDict sysTreeDict)
    {
        return toAjax(sysTreeDictService.updateSysTreeDict(sysTreeDict));
    }

    /**
     * 删除树形字典
     */
    @PreAuthorize("@ss.hasPermi('system:treeDict:remove')")
    @Log(title = "树形字典", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysTreeDictService.deleteSysTreeDictByIds(ids));
    }
}
